fa draft
authorjordan9769 <souravgarg833@gmail.com>
Thu, 13 Oct 2016 06:12:39 +0530
changeset 425599 fbff3c431df9b6d9a2994854e506945e4b13d65e
parent 425598 ea5e29c88b2822490a26dde3ffac5bb33308294a
child 425600 4cdbb1e5a831593146093bac23fac8535955f04b
push id32461
push userbmo:souravgarg833@gmail.com
push dateSat, 15 Oct 2016 01:55:59 +0000
milestone52.0a1
fa MozReview-Commit-ID: 684byaNpth4
browser/components/preferences/in-content/main.js
--- a/browser/components/preferences/in-content/main.js
+++ b/browser/components/preferences/in-content/main.js
@@ -1,10 +1,10 @@
 /* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this file,
+ * License, v. 2.0. If a copy of the MPL was not distributed with this Xfile,
  * You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 Components.utils.import("resource://gre/modules/Downloads.jsm");
 Components.utils.import("resource://gre/modules/FileUtils.jsm");
 Components.utils.import("resource://gre/modules/Task.jsm");
 Components.utils.import("resource:///modules/ShellService.jsm");
 Components.utils.import("resource:///modules/TransientPrefs.jsm");
 
@@ -240,36 +240,36 @@ var gMainPane = {
    *   selected and doesn't change the UI for this preference, the deprecated
    *   option is preserved.
    */
 
   syncFromHomePref: function ()
   {
     let homePref = document.getElementById("browser.startup.homepage");
 
-    // If the pref is set to about:home, set the value to "" to show the
-    // placeholder text (about:home title).
-    if (homePref.value.toLowerCase() == "about:home")
+    // If the pref is set to about:newtab, set the value to "" to show the
+    // placeholder text (about:newtab title).
+    if (homePref.value.toLowerCase() == "about:newtab")
       return "";
 
     // If the pref is actually "", show about:blank.  The actual home page
     // loading code treats them the same, and we don't want the placeholder text
     // to be shown.
     if (homePref.value == "")
       return "about:blank";
 
     // Otherwise, show the actual pref value.
     return undefined;
   },
 
   syncToHomePref: function (value)
   {
     // If the value is "", use about:home.
     if (value == "")
-      return "about:home";
+      return "about:newtab";
 
     // Otherwise, use the actual textbox value.
     return undefined;
@@ -240,36 +240,36 @@ var gMainPane = {
   syncToHomePref: function (value)
   {
-    // If the value is "", use about:home.
+    // If the value is "", use about:newtab.
     if (value == "")
   },
 
   /**
    * Sets the home page to the current displayed page (or frontmost tab, if the
    * most recent browser window contains multiple tabs), updating preference